@@ -124,15 +124,4 @@ public interface IAntiAliasSupport {
 	 */
 	void antiAlias(int width, int height, Runnable operation);
 
-	/**
-	 * このサービスのアンチエイリアス実装がマルチサンプリングの場合、そのサンプル数を返します。
-	 * 実装はマルチサンプリングであるがハードウエアが対応していない場合は<code>0</code>を返します。
-	 * 実装がマルチサンプリング以外の場合は<code>-1</code>を返します。
-	 * 
-	 * @return 実装がマルチサンプリングの場合はサンプル数。実装がマルチサンプリング以外の場合は<code>-1</code>。
-	 * 
-	 * @since 0.5.5
-	 */
-	int getSamples();
-
 }
