@@ -25,6 +25,7 @@ package ch.kuramo.javie.app.player;
 
 import java.awt.Dimension;
 import java.awt.EventQueue;
+import java.nio.ByteBuffer;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Iterator;
@@ -93,6 +94,10 @@ public class VideoCanvas extends Thread implements GLEventListener {
 
 	private static final boolean COCOA = SWT.getPlatform().equals("cocoa");
 
+	private static final boolean WIN32 = SWT.getPlatform().equals("win32");
+
+	private static final boolean WINXP = System.getProperty("os.name").equals("Windows XP");
+
 	private static final Time TIME0 = Time.fromFrameNumber(0, FrameDuration.FPS_29_97);
 
 
@@ -164,6 +169,10 @@ public class VideoCanvas extends Thread implements GLEventListener {
 
 	private final AtiIntelLock _atiIntelLock;
 
+	private final ByteBuffer _finishBuffer1;
+
+	private final ByteBuffer _finishBuffer2;
+
 
 	public VideoCanvas(Composite parent, MediaItem mediaItem, TimeKeeper timeKeeper) {
 		super("VideoCanvas: " + mediaItem.getName());
@@ -181,6 +190,14 @@ public class VideoCanvas extends Thread implements GLEventListener {
 		_intel = _glGlobal.isIntel();
 		_atiIntelLock = AtiIntelLock.get(_glGlobal);
 
+		if (WIN32 && !WINXP && _intel) {
+			_finishBuffer1 = ByteBuffer.allocate(4);
+			_finishBuffer2 = ByteBuffer.allocate(4);
+		} else {
+			_finishBuffer1 = null;
+			_finishBuffer2 = null;
+		}
+
 		_mediaItem = mediaItem;
 		_mediaInput = mediaInput;
 		_timeKeeper = timeKeeper;
@@ -280,6 +297,10 @@ public class VideoCanvas extends Thread implements GLEventListener {
 					public void run() {
 						if (_glCanvasRecord != null) {
 							_glCanvasRecord.awtFrame.repaint();
+
+							if (WIN32 && !WINXP) {
+								_canvas.repaint();
+							}
 						}
 					}
 				});
@@ -481,7 +502,12 @@ public class VideoCanvas extends Thread implements GLEventListener {
 				gl.glPopAttrib();
 			}
 
-			gl.glFinish();
+			if (WIN32 && !WINXP && _intel) {
+				gl.glReadPixels(0, 0, 1, 1, GL2.GL_RGBA,
+						GL2.GL_UNSIGNED_BYTE, _finishBuffer2);
+			} else {
+				gl.glFinish();
+			}
 
 		} finally {
 			_atiIntelLock.unlock();
@@ -861,7 +887,12 @@ public class VideoCanvas extends Thread implements GLEventListener {
 		gl.glFramebufferTexture2D(GL2.GL_FRAMEBUFFER,
 				GL2.GL_COLOR_ATTACHMENT0, GL2.GL_TEXTURE_2D, vb.getTexture(), 0);
 
-		gl.glFinish();
+		if (WIN32 && !WINXP /* && _intel */) {
+			gl.glReadPixels(0, 0, 1, 1, GL2.GL_RGBA,
+					GL2.GL_UNSIGNED_BYTE, _finishBuffer1);
+		} else {
+			gl.glFinish();
+		}
 
 		gl.glFramebufferTexture2D(GL2.GL_FRAMEBUFFER,
 				GL2.GL_COLOR_ATTACHMENT0, GL2.GL_TEXTURE_2D, 0, 0);
