@@ -29,11 +29,12 @@ import ch.kuramo.javie.api.IAudioBuffer;
 import ch.kuramo.javie.api.IObjectArray;
 import ch.kuramo.javie.api.annotations.Effect;
 import ch.kuramo.javie.api.annotations.Property;
+import ch.kuramo.javie.api.annotations.Effect.Categories;
 import ch.kuramo.javie.api.services.IAudioEffectContext;
 
 import com.google.inject.Inject;
 
-@Effect(id="ch.kuramo.javie.StereoMixer", category=Effect.AUDIO)
+@Effect(id="ch.kuramo.javie.StereoMixer", category=Categories.AUDIO)
 public class StereoMixer {
 
 	@Property(value="100", min="0", max="400")
