@@ -71,37 +71,21 @@ public abstract class GradientBase {
 		this.blendSupport = blendSupport;
 		this.tex1DSupport = tex1DSupport;
 		this.arrayPools = arrayPools;
+		blendSupport.setProgramsClass(blendSupport.getPremultAndMatteClass(true));
 	}
 
 	protected IVideoBuffer doGradientEffect(BlendMode blendMode, double opacity) {
-		IVideoBuffer original;
-		VideoBounds bounds;
-
-		if (blendMode == BlendMode.NONE) {
-			bounds = context.getPreviousBounds();
-			original = context.createVideoBuffer(bounds);
-		} else {
-			original = context.doPreviousEffect();
-			bounds = original.getBounds();
-		}
-
+		IVideoBuffer original = context.doPreviousEffect();
+		VideoBounds bounds = original.getBounds();
 		if (bounds.isEmpty()) {
 			return original;
 		}
 
-
 		IVideoBuffer gradient = null;
 		try {
 			gradient = createGradient(bounds);
 
-			if (blendMode == BlendMode.NONE && opacity == 1) {
-				IVideoBuffer result = gradient;
-				gradient = null;
-				return result;
-
-			} else {
-				return blendSupport.blend(gradient, original, null, blendMode, opacity, context);
-			}
+			return blendSupport.blend(gradient, original, null, blendMode, opacity, context);
 
 		} finally {
 			if (original != null) original.dispose();
